Contributing
============

.. _contributor-communication:

Communication
-------------

pyglet communication occurs mostly in our `Discord server <https://discord.gg/QXyegWe>`_.

Issue Tracker
-------------

You can use the `issue tracker <https://github.com/pyglet/pyglet/issues>`_
to report any bug or compatibility issue. If your issue is more complex than what can be
covered in a ticket, also consider joining the `Discord server <https://discord.gg/QXyegWe>`_.

Getting the latest development version
--------------------------------------

The repository can be found `here <https://github.com/pyglet/pyglet>`_;
it hosts the source, documentation, examples, and development tools. You can
get the latest version of the code using:

.. code-block:: bash

    # clone over https
    git clone https://github.com/pyglet/pyglet.git

    # or clone over ssh
    git clone git@github.com:pyglet/pyglet.git

Contributing to the source
--------------------------

If you want to contribute to pyglet, we suggest the following:

* Fork the `official repository <https://github.com/pyglet/pyglet/fork>`_
* Apply your changes to your fork
* Submit a `pull request <https://github.com/pyglet/pyglet/pulls>`_
  describing the changes you have made
* Alternatively, you can create a patch and submit it to the issue tracker.

Contributing to the documentation
---------------------------------

When asking to include your code in the repository, check that you have
addressed its respective documentation, both within the code and the API
documentation. It is very important to all of us that the documentation matches
the latest code and vice-versa.

Consequently, an error in the documentation, either because it is hard to
understand or because it doesn't match the code, is a bug that deserves to
be reported on a ticket.

A good way to start contributing to a component of pyglet is by its
documentation. When studying the code you are going to work with, also read
the associated docs. If you don't understand the code with the help of the
docs, it is a sign that the docs should be improved.

Contact
-------

pyglet is developed by many individual volunteers, and there is no central
point of contact. If you have a question about developing with pyglet, or you
wish to contribute, please join the `Discord server <https://discord.gg/QXyegWe>`_.


For legal issues, please contact
`Alex Holkner <mailto:Alex.Holkner@gmail.com>`_.
